/*
 * Copyright (c) 1995-2000 Sun Microsystems, Inc. All Rights Reserved.
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *    
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
*/

package deviceaccess.hpprinterdriver;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.service.device.Device;
import org.osgi.service.device.Driver;

import java.util.Hashtable;
import java.util.Enumeration;

/**
 * This is a HP Printer Driver service that presumably will be
 * downloaded via devicemanager service that talks to the 
 * driverlocator service  on to the gateway 
 */
class HPPrinterDriver implements Driver {

    private HPPrinterDevice hpPrinterDevice;

    private final transient static String DEVICE_CLASS = 
        "org.osgi.service.device.Device";

    private final static Hashtable driverKeys = new Hashtable();    

    BundleContext bc;

    public HPPrinterDriver(BundleContext bc) {
        this.bc = bc;

        // this hashtable is used internally to do a 
        // match on the DRIVER_ID and device properties
        driverKeys.put("device_make", "hp");        
        driverKeys.put("device_category", "usb");
        driverKeys.put("device_class", "printer");
        driverKeys.put("device_model", "laserjet");
        driverKeys.put("device_serial", "5.7");
    }

    /**
     * Match function called by DeviceManager during mathing process.
     * <p>
     * The service which bids highest gets connection 
     * <code>public void attach(ServiceDescription s)</code><br/>
     * called with the same service descriptor as match().</p>
     *
     * Compares the properties the device registered, to the ones
     * registered by this driver service as listed in driverKeys array 
     * and computes the total number of matches on property values.
     *
     * @param sr ServiceReference to be matched
     * @return integer not less than Device.MATCH_NONE
     */
    public int  match(ServiceReference sr)
        throws Exception
    {
        String[] props = sr.getPropertyKeys();
        int match = 0;

        for (Enumeration e = driverKeys.keys(); e.hasMoreElements();) {
            String deviceKey = null;
            String driverKey = (String) e.nextElement();
            for (int j = 0; props != null && j < props.length; j++) {
                deviceKey = props[j];
                if (driverKey.equals(deviceKey)) {
                    String driverValue = 
                        (String) driverKeys.get(driverKey);
                    String deviceValue = 
                        (String) sr.getProperty(deviceKey);

                    if ((driverValue != null &&
                         deviceValue != null &&
                         driverValue.equals(deviceValue))) {
                        match++;
                        break;                        
                    }
                }
            }
        }

        return match;
    }

    /**
     * DeviceManager has decided this was the best matching service
     * - creates a dependency between this bundle and the device
     *   service represented by sr.     
     * - the driver is expected to register a new device service, 
     *   corresponding to it's actual physical function.
     *
     * @param sr ServiceReference triggering the driver loading.
     * @return null if this driver succeded in attach, non-null if a 
     * valid id to driverlocator
     */
    public String attach (ServiceReference sr) 
        throws Exception
    {
        Device originalDevice = (Device)bc.getService(sr);

        if (originalDevice != null) {
            Hashtable dictionary = new Hashtable();
            hpPrinterDevice = new HPPrinterDevice();
            
            bc.registerService(DEVICE_CLASS,
                                     hpPrinterDevice,
                                     dictionary);
        }

        return null;
    }      
    
}
