/*
 * Copyright (c) 1995-2000 Sun Microsystems, Inc. All Rights Reserved.
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *    
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
*/

package deviceaccess.usbdriver;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;

import java.util.Hashtable;

/**
 *  Bundle Activator for USBDriver service 
 */
public class USBDriverActivator implements BundleActivator {
    
    private USBDriver usbdriver;
    private USBDevice usbdevice;

    private final static String DEVICE_CLASSNAME = 
        "org.osgi.service.device.Device";
    private final static String DRIVER_CLASS = 
        "org.osgi.service.device.Driver";

    private final String DRIVER_ID = "DRIVER_ID";
    private final static String DEVICE_CATEGORY = "device_category";
    private final static String DEVICE_CLASS = "device_class";
    private final static String DEVICE_MAKE = "device_make";
    private final static String DEVICE_MODEL = "device_model";
    private final static String DEVICE_REVISION = "device_revision";
    private final static String DEVICE_SERIAL = "device_serial";

    /**
     * start the USBDriver service and register a USBDevice service
     * 
     * @param bc The driver1's bundle context
     */
    public void start(BundleContext context)
        throws Exception 
    {
        Hashtable driverDictionary = new Hashtable();
        Hashtable deviceDictionary = new Hashtable();

        // FOR usbdriver:
        driverDictionary.put(DRIVER_ID, "usb");
        usbdriver = new USBDriver();        
        // register usbdriver service
        context.registerService(DRIVER_CLASS,
                                usbdriver,
                                driverDictionary);

        // Here it is registering a USBPrinter device service
        // It could however register a USBMouse device service if
        // it detected that the properties were identifying a mouse

        // FOR usbdevice:
        // The driver gets this information about the device that
        // plugs in over the wire and registers this device service
        deviceDictionary.put(DEVICE_CATEGORY,
                       new String("usb"));
        deviceDictionary.put(DEVICE_CLASS,
                       new String("printer"));
        deviceDictionary.put(DEVICE_MAKE,
                       new String("hp"));
        deviceDictionary.put(DEVICE_MODEL,
                       new String("laserjet"));
        deviceDictionary.put(DEVICE_SERIAL,
                       new String("5.7"));
        usbdevice = new USBDevice();
        // register usbdevice service
        context.registerService(DEVICE_CLASSNAME,
                                usbdevice,
                                deviceDictionary);
                                        
    }

    /**
     * clean up if any
     *
     * @param bc The Driver's bundle context
     */

    public void stop(BundleContext context) 
        throws Exception
    {

    }

}
