/*
 * Copyright (c) 1995-2000 Sun Microsystems, Inc. All Rights Reserved.
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *    
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
*/

package events;

import org.osgi.framework.*;

class MyListener 
implements FrameworkListener, BundleListener, ServiceListener 
{
    public void frameworkEvent(FrameworkEvent e) {
	switch (e.getType()) {
	case FrameworkEvent.STARTED:
	    println("The framework has started.");
	    break;
	case FrameworkEvent.ERROR:
	    Throwable t = e.getThrowable();
	    Bundle b = e.getBundle();
	    println("Framework error occurred:");
	    if (b != null)
		println(b.getLocation());
	    if (t != null)
		t.printStackTrace();
	    break;
	}
    }

    public void bundleChanged(BundleEvent e) {
	Bundle b = e.getBundle();
	switch (e.getType()) {
	case BundleEvent.INSTALLED:
	    println(b.getLocation() + " has been installed");
	    break;
	case BundleEvent.STARTED:
	    println(b.getLocation() + " has been started");
	    break;
	case BundleEvent.STOPPED:
	    println(b.getLocation() + " has been stopped");
	    break;
	case BundleEvent.UPDATED:
	    println(b.getLocation() + " has been updated");
	    break;
	case BundleEvent.UNINSTALLED:
	    println(b.getLocation() + " has been uninstalled");
	    break;
	}
    }

    public void serviceChanged(ServiceEvent e) {
	ServiceReference ref = e.getServiceReference();
	switch (e.getType()) {
	case ServiceEvent.REGISTERED:
	    println(ref + " has been registered by "+
		    ref.getBundle().getLocation());
	    break;
	case ServiceEvent.UNREGISTERING:
	    println(ref + " is being unregistered");
	    break;
	case ServiceEvent.MODIFIED:
	    println("properties of "+ref+" have been modified:");
	    String[] keys = ref.getPropertyKeys();
	    for (int i=0; i<keys.length; i++)
		println(keys[i] + "=" + ref.getProperty(keys[i]));
	    break;
	}
    }
    
    void println(String msg) {
	System.out.println("events: "+msg);
    }
}
