/**
 * @(#)HomePortalImpl.java	1.1 00/08/08
 *
 * Copyright 2000 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 */

package homeportal;

import org.osgi.service.http.*;
import org.osgi.framework.*;
import java.util.*;

public class HomePortalImpl implements BundleActivator, ServiceListener {

      /** I18N strings  */
    private static final LocalizedStrings ls = (LocalizedStrings) 
        java.util.ResourceBundle.getBundle(
            "homeportal.LocalizedStrings");

    private static final String HTTP_INTERFACE =
        "org.osgi.service.http.HttpService";
    private static final String HTTP_BASIC_INTERFACE =
        "com.sun.jes.service.http.auth.basic.BasicSchemeHandler";
    private static final String HTTP_USERS_INTERFACE =
        "com.sun.jes.service.http.auth.users.UserPasswordService";

    private ServiceRegistration adminReg;
    private BundleContext bc;

    /*
     * The HTTP service which we currently have our UI registered with
     */
    private HttpService httpService;

    /*
     * A reference to our http service
     */
    private ServiceReference httpReference;
    // references to the 'basic autharization' and http users services
    private ServiceReference basicRef;
    private ServiceReference upsRef;


    public void start( BundleContext bc ) {

      this.bc = bc;
      this.httpReference = null;
      this.httpService = null;
      this.basicRef = null;
      this.upsRef = null;

      /*
       * Synchronize this block so, for example, we dont get
       * a notification of an http service registration before
       * we can get the servicereference
       */
      synchronized (this) {
        try {
          String filter = "(|(objectClass="+HomePortalImpl.HTTP_INTERFACE+")"+
                          "(objectClass="+HomePortalImpl.HTTP_BASIC_INTERFACE+")"+
                          "(objectClass="+HomePortalImpl.HTTP_USERS_INTERFACE+"))";
          this.bc.addServiceListener(this, filter);
        } catch (InvalidSyntaxException info) {
          info.printStackTrace();
        }

        this.setup(bc.getServiceReference(HomePortalImpl.HTTP_INTERFACE),
                   bc.getServiceReference(HomePortalImpl.HTTP_BASIC_INTERFACE),
                   bc.getServiceReference(HomePortalImpl.HTTP_USERS_INTERFACE));
      }
    }

    private synchronized void setup(ServiceReference anHTTPReference,
                                    ServiceReference anHTTPBasicReference,
                                    ServiceReference anHTTPUsersReference) {
      /*
       * This is synchronized so we don't inadvertantly have our
       * http service removed while we are in the process of using it.
       */
      if (this.httpReference == null)
        this.httpReference = anHTTPReference;
      if (this.basicRef == null)
        this.basicRef = anHTTPBasicReference;
      if (this.upsRef == null)
        this.upsRef = anHTTPUsersReference;


      //proceed only if all required services are available
      if(this.httpReference != null && this.basicRef != null && this.upsRef != null) {

        if(this.httpService == null) {
          this.httpService = (org.osgi.service.http.HttpService)
              bc.getService(this.httpReference);
        }

        try {
          HomePortalServlet hps = new HomePortalServlet(bc, this.basicRef, this.upsRef);
          try {
            httpService.registerServlet("/", hps, null, hps );
            httpService.registerResources("/images/homeportal",
                                        "/homeportal",
                                        null);
          }
          catch(NamespaceException nse) {
            nse.printStackTrace();
          }
        }
        catch ( Exception e ) {
          e.printStackTrace();
        }

      }

    }


    public void stop( BundleContext c ) {

      unregisterServlet();

      this.httpReference = null;
      this.httpService = null;
      this.basicRef = null;
      this.upsRef = null;

    }

    private void unregisterServlet() {

      if (this.httpService != null) {
        try {
          this.httpService.unregister("/");
          this.httpService.unregister("/images/homeportal");

        } catch (IllegalArgumentException info) {
          // ignore it.  if we can't unregister, we can't unregister.
        }
      }

    }


    /**
     * Cope with the appearance and disappearance of
     * HTTP services
     *
     * @param event information about the change of a service (not null)
     */
    public synchronized void serviceChanged(ServiceEvent event) {
        /*
         * Synchronized to prevent problems with access to
         * the http service
         */
        ServiceReference ref = null;
        int i;


        switch (event.getType()) {
        case ServiceEvent.REGISTERED:
            ref = event.getServiceReference();
            String[] objclass = (String[])ref.getProperty("objectClass");
            for(i=0; i < objclass.length; i++) {
              if(objclass[i].equals(HomePortalImpl.HTTP_INTERFACE)) { 
                //call setup() only if the reference to a dependent service
                //is null, otherwise we'll end up replacing an existing service
                //with a new one.
                if (this.httpReference == null) {
                  this.httpReference = ref;
                  this.setup(this.httpReference, this.basicRef, this.upsRef);
                  break;
                }
              }
              else if(objclass[i].equals(HomePortalImpl.HTTP_BASIC_INTERFACE)) {
                if (this.basicRef == null) {
                  this.basicRef = ref;
                  this.setup(this.httpReference, this.basicRef, this.upsRef);
                  break;
                }
              }
              else if(objclass[i].equals(HomePortalImpl.HTTP_USERS_INTERFACE)) { 
                if (this.upsRef == null) {
                  this.upsRef = ref;
                  this.setup(this.httpReference, this.basicRef, this.upsRef);
                  break;
                }
              }
            }
            
            break;
        case ServiceEvent.UNREGISTERING:
            ref = event.getServiceReference();
            if (ref.equals(this.httpReference)) {
              unregisterServlet();
              this.httpReference = null;
              this.httpService = null;
            }
            else if (ref.equals(this.basicRef)) {
              unregisterServlet();
              this.basicRef = null;
            }
            else if (ref.equals(this.upsRef)) {
              unregisterServlet();
              this.upsRef = null;
            }
            break;
        case ServiceEvent.MODIFIED:
        default:
            // ignore all others
            break;
        }
    }

}
