/**
 * @(#)HomePortalServlet.java	1.1 00/08/08
 *
 * Copyright 2000 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 */

package homeportal;

import org.osgi.framework.*;
import org.osgi.service.http.*;
import com.sun.jes.service.http.HttpRegistration;
import com.sun.jes.service.http.HttpAdmin;
import com.sun.jes.service.http.auth.basic.*;
import com.sun.jes.service.http.auth.users.*;
import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import java.util.*;
import java.net.URL;

public class HomePortalServlet extends HttpServlet implements HttpContext {

     /** I18N strings  */
    private static final LocalizedStrings ls = (LocalizedStrings) 
        java.util.ResourceBundle.getBundle(
            "homeportal.LocalizedStrings");

    private HttpServletRequest myRequest;
    private HttpServletResponse myResponse;
    private PrintWriter out;
    private BundleContext bc;

    private BasicSchemeHandler basic;

    UserPasswordService ups;

    private boolean isAdmin = false;

    public HomePortalServlet( BundleContext bc, 
                              ServiceReference anHTTPBasicReference,
                              ServiceReference anHTTPUsersReference) {

	super();
	this.bc = bc;

	basic = (BasicSchemeHandler) bc.getService(anHTTPBasicReference);

	ups = (UserPasswordService) bc.getService(anHTTPUsersReference);
    }

    public void doGet(HttpServletRequest request, HttpServletResponse response)
		throws ServletException, IOException {
        this.myRequest = request;
        this.myResponse = response;
        this.myResponse.setContentType("text/html");
        this.out = new java.io.PrintWriter( response.getWriter() );

	htmlBegin();

        this.displayServices();
	displayChangePassword();

	htmlEnd();
   }

   void htmlBegin() {

     this.out.println("<HTML><HEAD><TITLE>");
     this.out.println(ls.welcomeHomePortal());
     this.out.println( "</TITLE></HEAD>" );
     this.out.println( "<BODY BACKGROUND=\"/images/homeportal/backrnd_tile.gif\">" );
     this.out.println( "<img src=\"/images/homeportal/dotcom_title.gif\"><BR>" );

   }

   private void displayServices() {

     this.out.println(ls.servicesDescriptor());

     try {
        HttpAdmin httpService =
            (HttpAdmin)this.bc.getService(
                  bc.getServiceReference( "com.sun.jes.service.http.HttpAdmin") );
	HttpRegistration[] regs = httpService.getServletRegistrations();
        for ( int i=0; i<regs.length; i++ ) {

	    Servlet servlet = regs[i].getServlet();
	    ServletConfig servletConfig = servlet.getServletConfig();
	    String presentationStr =
                servletConfig.getInitParameter(
                    "com.sun.jes.service.homeportal.displayName" );
	    String presentationImageAlias =
                servletConfig.getInitParameter(
                    "com.sun.jes.service.homeportal.displayImageURL" );
	    // if both of these are null, this servlet is not a UI
	    // Presenting one
	    if ( presentationStr != null ) {
		URL aServletURL = regs[i].getURL("*");
		if ( presentationImageAlias != null ) { // present the icon too
		    this.out.println( "<img src=\"" + presentationImageAlias + 
				    "\">" );
		}
		this.printLink( aServletURL.getFile(),
				presentationStr,
				null ); // null target ensures same browser
		this.out.print("<BR><BR>");
	    }
            else if ( presentationImageAlias != null ) { //only icon, no text
              URL aServletURL = regs[i].getURL("*");
              this.out.println("<a href=\"");
              this.out.println(aServletURL.getFile()); 
              this.out.print( "\">" );
              this.out.println( "<img src=\"" + presentationImageAlias + 
				    "\">" );
              this.out.print( "</A>" );
            }
        }
        if(isAdmin == true) {
	  this.out.print("<BR><BR>");
          this.out.print( "<img src=\"/images/homeportal/sel.gif\" WIDTH=\"20\" HEIGHT=\"22\" ALIGN=\"BOTTOM\" BORDER=\"0\">" );
          this.printLink("/admin", "  JES Management Panel", null);
	  this.out.print("<BR><BR>");
        }
     } catch ( Exception e ) {
	 e.printStackTrace();
     }

   }

   void displayChangePassword() {

       this.out.print("<BR><BR>");
       this.out.print( "<img src=\"/images/homeportal/sel.gif\" WIDTH=\"20\" HEIGHT=\"22\" ALIGN=\"BOTTOM\" BORDER=\"0\">" );
       this.printLink("/chgp", "  Change Password", null);
       this.out.print("<BR><BR>");

   }


   void htmlEnd() {
       
       this.out.println("</BODY></HTML>");
       this.out.close();
   }

    public void doPost (
      HttpServletRequest req,
      HttpServletResponse res )
        throws IOException, ServletException {
      this.doGet ( req, res );
    }

    protected void printLink( String location, String label,
                             String target ) {
        this.out.print( "<A HREF=\"" );
        this.out.print( location );
        if ( target != null ) {
            this.out.print( "\" TARGET=\""+target );
        }
        this.out.print( "\">" );
        this.out.print( "<font face=\"Arial, Helvetica, sans-serif\" color=\"#ffffff\" size=\"5\">");
        this.out.print( label );
        this.out.print("</font>");
        this.out.print( "</A>" );
    }



    public URL getResource( String str ) {

	return null;

    }

    public String getMimeType(String str) {

	return null;

    }

    /* The 'http' service calls this method for each request to the
     * servlet. When the following method returns 'false', the
     * browser pops a dialog for the user to enter 'user id' and 
     * 'password'.
     */
    public boolean handleSecurity(HttpServletRequest req, 
			HttpServletResponse res) {

	BasicSchemeHandler.Response response = basic.getResponse(req);
	if ( response != null ) {
	    String user = response.getName();
	    String password = response.getPassword();
	    if ( check(user, password) ) {
                if (ups.isAdmin(user))
                  isAdmin = true;
		return true;
	    }
	}

	try {
	    basic.sendChallenge(res, "homeportal");
	}
	catch( IOException ioe ) {
	    ioe.printStackTrace();
	}

	return false;
    }

    boolean check(String user, String pass) {

	boolean result = false;

	try {
	    result = ups.checkPassword(user, pass);
	}
	catch( IllegalArgumentException iae ) {
	    iae.printStackTrace();
	    result = false;
	}

	return result;
    }

}
