/*
 * Copyright (c) 2000 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 * This class is a thread to listen and accept connections on an SSL
 * server socket. The server socket is created by JsseApiServer, but
 * spawning a thread to do an accept on the socket means that the
 * JsseApiServer activator will not block a return to the framework
 * prompt, so that other bundles (e.g., the JsseApiClient.jar service)
 * can also be started up.
 */

package jsseapiserver;

import java.net.*;
import java.io.*; 

public class SocketListener implements Runnable
{
    private ServerSocket ss = null;
    private InetAddress myAddr = null;

    public SocketListener( ServerSocket ss, InetAddress addr )
    {
        this.ss = ss;
        this.myAddr = addr;
        return;
    }

    /**
     * This thread actually waits for a socket connection and
     * handles it.
     */
    public void run()
    {
        // Accept a connection
        Socket socket;
        try {
            System.out.println( "listening on socket " + ss );
            
            socket = ss.accept();
        } catch (IOException e) {
            // This is most likely because the service was stopped
            // while we were waiting for a connection.
            try {
                ss.close();
            }
            catch( IOException anotherE ) {
                // Eat it
            }
            return;
        }

        // Read a request and respond.
        try {
            DataOutputStream out =
                new DataOutputStream( socket.getOutputStream() );
            try {
                // get request header
                BufferedReader in = new BufferedReader(
                                        new InputStreamReader(
                                            socket.getInputStream() ) );
                String line = in.readLine();
                if( line == null ) {
                    System.out.println( "Empty request header" );
                    return;
                }
        
                String header = "";
                if ( line.startsWith( "GET " ) ) {
                    line = line.substring(4 , line.length() - 1 ).trim();
                    int index = line.indexOf( ' ' );
                    if ( index != -1 ) {
                        header = line.substring( 0, index );
                    }
                }
                if( header.length() == 0 ) {
                    System.out.println( "Malformed request header" );
                    return;
                }

                // eat the rest of header
                do {
                    line = in.readLine();
                    System.out.println( line );
                } while( line.length() != 0 );

                // send response
                try {
                    out.writeBytes("HTTP/1.0 200 OK\r\n");
                    out.writeBytes("Content-Type: text/html\r\n\r\n");
                    out.writeBytes( "Java Embedded Server JSSE server socket test listening on host " +
                                    myAddr.getHostName() );
                    out.flush();
                } 
                catch (IOException ie) {
                    System.out.println( "IOException writing response" );
                    return;
                }
            } catch ( Exception e ) {
                System.out.println( "Exception reading request" );
                return;
            }
        }
        catch (IOException ex) {
            ex.printStackTrace();
            return;
        }
        finally {
            try {
                if( socket != null )
                    socket.close();
            }
            catch (IOException e) {
                System.out.println( "IOException closing socket" );
                return;
            }
        }
        return;
    }
}
