/*
 * Copyright 2000 Sun Microsystems, Inc. All Rights Reserved.
 *
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information"). You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *
 *
 * HTTP Server Mirror
 *
 * This HTTP server responds to all requests by sending back (or mirroring)
 * the exact contents of the HTTP request.  This is useful for debugging
 * HTTP clients.
 *
 * Use: java MessageProcessor <port>
 *
 */

package log2http;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.net.Socket;
import java.net.ServerSocket;

public class HttpServer implements Runnable {

  private static final String MY_LOG = "mylog";
  private static final int MY_PORT = 9092;

  public static void main( String[] args ) {
    try {

      // Store the log in the current directory
      File logfile = new File( MY_LOG );
      PrintWriter logwriter = new PrintWriter(new FileWriter( logfile ));

      // Listen on the port, accept connections and spawn a thread to
      // read and store the messages.
      //int port = Integer.parseInt( args[0] );        // Listen on user's port
      int port = ( MY_PORT );                        // Listen on hard-coded port
      ServerSocket ss = new ServerSocket( port );    // The socket to be used
      System.out.println( "*ready" );
      for( ;; ) {
        Socket client = ss.accept();                 // Wait for a connection
        HttpServer hs = new HttpServer( client, logwriter );
      }
      //logwriter.close();                           // open 24x7 for messages!

    } catch (Exception e) {
      System.err.println( "Error: " + e.getMessage() );
    }
  }


  /*
   * Start up a thread to receive message POSTs and then store those
   * messages into the log file.
   *
   */
  Socket client;
  PrintWriter logwriter;
  public HttpServer( Socket client, PrintWriter logwriter ) {

    this.client = client;
    this.logwriter = logwriter;

    Thread x = new Thread( this );
    x.start();

  }


  /*
   * This is the thread that receives messages and stores them in the log file.
   */
  public void run() {
    try {
      System.out.println();
      System.out.println( "Received request" );

      // Get streams to talk to the client
      BufferedReader in =
        new BufferedReader(new InputStreamReader( client.getInputStream() ));
      PrintWriter out =
        new PrintWriter(new OutputStreamWriter( client.getOutputStream() ));

      // Send the HTTP response
      System.out.println( "Sending HTTP response..." );
      out.print( "HTTP/1.0 200\nContent-Type: text/plain\n" );

      // Show messages as they are received and store them in the file.
      String line;
      while( (line = in.readLine()) != null ) {
        if( line.length() == 0 )
          break;
        System.out.println( "Received: " + line );
        logwriter.println( line );  // write the message to the log
      }
      logwriter.flush();

      out.close();
      in.close();

      client.close();

    } catch (IOException e) {  /* Ignore exceptions */
    }

  }

}

