/* @(#)SnoopActivator.java	1.4 00/08/23
 * Copyright (c) 1995-2000 Sun Microsystems, Inc. All Rights Reserved.
 * This software is the confidential and proprietary information of Sun
 * Microsystems, Inc. ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only in
 * accordance with the terms of the license agreement you entered into
 * with Sun.
 *    
 * SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
*/
package snoopbasic;

import java.util.*;
import java.net.*;

import javax.servlet.*;
import javax.servlet.http.*;
import org.osgi.framework.*;
import org.osgi.service.http.*;
import com.sun.jes.service.http.auth.basic.*;

public class SnoopActivator implements BundleActivator, ServiceListener {

    SnoopServlet snoop = null;
    HttpService http;
    BasicSchemeHandler basic;
    ServiceReference httpref;
    ServiceReference httpauthref;
    final String SERVLET_ALIAS = "/snoopbasic";
    BundleContext bundleContext;

    public void start(BundleContext bc) throws BundleException {

	bundleContext = bc;

	snoop = new SnoopServlet(this);

	httpref = bc.getServiceReference("org.osgi.service.http.HttpService");
	if ( httpref != null ) {
	    http = (HttpService) bc.getService(httpref);
	    httpRegister();
	}

	httpauthref = 
		bc.getServiceReference("com.sun.jes.service.http.auth.basic.BasicSchemeHandler");
	if ( httpauthref != null ) {
	    basic = (BasicSchemeHandler) bc.getService(httpauthref);
	}

	try {
	    bc.addServiceListener(this, 
		"(objectClass=org.osgi.service.http.HttpService)");
	    bc.addServiceListener(this, 
		"(objectClass=com.sun.jes.service.http.auth.basic.BasicSchemeHandler)");
	}
	catch(InvalidSyntaxException ise) {
	    ise.printStackTrace();
	}

    }

    public synchronized void serviceChanged(ServiceEvent event) {

	if ( event.getType() == ServiceEvent.UNREGISTERING ) {

	    if ( event.getServiceReference().equals(httpref) ) {
		httpUnregister();
		httpref = null;
		http = null;
	    } else if ( event.getServiceReference().equals(httpauthref) ) {
		httpauthref = null;
		basic = null;
	    } 

	}
	else if ( event.getType() == ServiceEvent.REGISTERED ) {

	    httpref = bundleContext.getServiceReference(
			       "org.osgi.service.http.HttpService");
	    if ( httpref != null && http == null ) {
		http = (HttpService) bundleContext.getService(httpref);
		httpRegister();
	    }

	    httpauthref = bundleContext.getServiceReference("com.sun.jes.service.http.auth.basic.BasicSchemeHandler");
	    if ( httpauthref != null && basic == null ) {
		basic = (BasicSchemeHandler) bundleContext.getService(httpauthref);
	    }

	}
    }

    private void httpRegister() {

	try {
	    http.registerServlet(SERVLET_ALIAS, snoop, null, snoop);
	}
	catch(ServletException se) {
	    se.printStackTrace();
	}
	catch(NamespaceException nse) {
	    nse.printStackTrace();
	}

    }

    void httpUnregister() {

	try {
	    http.unregister(SERVLET_ALIAS);
	}
	catch(IllegalArgumentException iae) { }
    }

    BasicSchemeHandler getBasicSchemeHandlerRef() {

	return basic;
    }

    public void stop(BundleContext bc) throws BundleException {

	if ( http != null ) {
	    httpUnregister();
	}

    }


}
