/*
 * Copyright 2000 Sun Microsystems, Inc. All Rights Reserved. 
 * 
 * This software is the confidential and proprietary information of Sun 
 * Microsystems, Inc. ("Confidential Information"). You shall not 
 * disclose such Confidential Information and shall use it only in 
 * accordance with the terms of the license agreement you entered into 
 * with Sun. 
 *
 * 
 * TimerExample
 *
 * A simple example of how to use the Timer service to schedule a task.
 * In this case, the task prints a message at regular intervals for a
 * short time.  The task is then cancelled, followed by the timer itself.
 * When the timer is cancelled, all active tasks for this bundle are
 * cancelled.
 */

package timerexample;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import com.sun.jes.service.timer.TimerService;
import com.sun.jes.service.timer.TimerTask;

public class TimerExample {

    // Delays (milliseconds)
    private static final long  START_DELAY = 500;  // Delay before task execution begins
    private static final long REPEAT_DELAY = 250;  // Delay between execution of task

    TimerExample( BundleContext bc ) {
        try {

            // Attempt to get the Timer service reference
            getServices( bc );
            if (timer == null) {
                System.err.println( "Unable to get Timer service reference!" );
                return;
            }

            // Schedule and run a new TimerTask
            System.out.println( "Scheduling task" );
            TimerTask task = timer.schedule( new Runnable() {
                public void run() {
                    System.out.println( "Task is running");
                }
            }, START_DELAY, REPEAT_DELAY );

            // Allow the task to execute for a while
            Thread.sleep( 2000 );

            // Cancel the task
            System.out.println( "Cancelling the task" );
            task.cancel();

            // Shut down the timer for this bundle
            System.out.println( "Cancelling the timer" );
            timer.cancel();
            timer = null;

        } catch (Exception e) {
            System.err.println( e.getMessage() );
        }
    }

    /*
     * Get the Timer service reference.
     */
    public final static String TIMER_CLASS = "com.sun.jes.service.timer.TimerService";
    private TimerService timer = null;  // Reference to the Timer service object
    synchronized void getServices( BundleContext bc ) {
        ServiceReference sr = null;

        if (timer == null) {
            if ((sr = bc.getServiceReference( TIMER_CLASS )) != null) {
                timer = (TimerService) bc.getService( sr );
            }
        }
    }

}
