# Copyright (c) 1995-2000 Sun Microsystems, Inc. All Rights Reserved.
# This software is the confidential and proprietary information of Sun
# Microsystems, Inc. ("Confidential Information").  You shall not
# disclose such Confidential Information and shall use it only in
# accordance with the terms of the license agreement you entered into
# with Sun.
#    
# SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
# SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
# SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
# THIS SOFTWARE OR ITS DERIVATIVES.
############################################################################
# 
# GNU common makefile for JES examples
# 
# These makefiles assume:
# 1.  Either the examples are built in place in <jes install dir>/examples,
#     or, JES_INSTALL_DIR is set to the pathname of where JES is installed.
#
# 2.  Either JES_JAVA_HOME is set to the pathname of a JDK installation,
#     or javac and jar are on your PATH.
# 
# The output from building the examples is left in BUILD_DIR whose
# default value is ..../examples/build
# These GNU makefiles can be used on Solaris, Windows/CYGWIN, and Windows/mks.
# See the accompanying README file for more information.
############################################################################
#
# Each GNUMakefile in an example must/may define the following variables and then 
# include this file.
#
#    SRCDIR:       The name of the example directory.
#                  Required.
#
#    JAVA_FILES:   .java files to be compiled. The
#                  default is *.java
#
#    PROP_FILES:   .properties files to include.  The
#                  default is *.properties
#
#    EXTRA_FILES:  Extra files to include in the .jar file.  This is a
#                  list of pathnames of the files, relative ./build/classes.
#                  EG:
#                       EXTRA_FILES = example89/T1.class example100/fred.T2.class
#                  would cause the .jar file to include 
#                           example89/T1.class
#                           example100/T2.class
#
#    JAR_NAME:     The name of the jar file to be built.  The
#                  default is $(SRCDIR).jar.  If the value is 'none',
#                  then no jar will be built.
#
#    EXTRA_CLASSPATH:  A classpath segment to include in the compiliation, eg:
#                       EXTRA_CLASSPATH = \
#                          $(JES_INSTALL_DIR)/bundles/log.jar:$(JES_INSTALL_DIR)/bundles/http.jar
#                      WARNING:
#                             Be sure you don't use := when defining EXTRA_CLASSPATH if the
#                             definition references a macro which hasn't been defined
#                             yet such as JES_INSTALL_DIR in the above example.
#
#    DOTS:         The the relative path from the example dir to the examples dir.
#                  The default is .. meaning that the example dir is directly 
#                  contained in the examples dir.  So, this only has to be
#                  defined if there are intermediate dirs.  For example,
#                  suppose the example dir is
#                     examples/group/myexample
#                  Then the GNUmakefile in myexample/ should contain:
#                         SRCDIR = group/myexample
#                         JAR_NAME = myexample.jar
#                         DOTS  = ../..
#                  And the package for the .java files should be  group.myexample.
#
############################################################################

# LOCALUNIX is where the unix commands are located.
# On NT CYGWIN and MKS, we assume that these commands are in your PATH.
ifdef LOCALUNIX 
    # We don't want \s in this
    LOCALUNIX := $(subst \,/,$(LOCALUNIX))
    os = $(shell $(LOCALUNIX)/uname)
else
    # Determine the OS/arch.
    os = $(shell uname)
endif

ifeq "$(findstring CYG, $(os))" "CYG"
   ARCH = win32
   OS   = cygwin
   BIN  =
   CPSEP = ";"
else
   ifeq "$(findstring NT, $(os))" "NT"
       ARCH = win32
       OS   = mks
       BIN  =
       CPSEP = ";"
   else
      ifeq "$(findstring SunOS, $(os))" "SunOS"
          ARCH = solaris
          OS   = solaris
          BIN  = /bin/
      else
          ARCH = linux
          OS   = linux
          # On linux, not everything is in /bin; some is in /usr/bin
          # so, we will just require it to be on the PATH
          BIN =    
     endif
     CPSEP = :
   endif
endif


# This should be defined if examples have multiple levels of directories.
ifndef DOTS
    DOTS =..
endif

# The path to where JES has been installed; if it is not an
# absolute path, it is relative to the directory where gnumake is
# invoked.
ifndef JES_INSTALL_DIR
    # Assume we are in <install-dir>/examples/xxxx
    JES_INSTALL_DIR := ../../$(DOTS)
    ifneq "$(shell $(BIN)test -e $(JES_INSTALL_DIR)/lib/framework.jar; $(BIN)echo $$?)" "0"
#    ifneq "$(shell /usr/bin/test -e $(JES_INSTALL_DIR)/lib/framework.jar; $(BIN)echo $$?)" "0"
all::
	@$(BIN)echo "Error: You must set JES_INSTALL_DIR to the pathname of a JES installation."
	@exit 1
    endif
else
    ifneq "$(shell $(BIN)test -e $(JES_INSTALL_DIR)/lib/framework.jar; $(BIN)echo $$?)" "0"
all::
	@$(BIN)echo "Error: JES_INSTALL_DIR does not point at a JES installation."
	@exit 1
    endif
endif

JES_INSTALL_DIR := $(shell (cd $(JES_INSTALL_DIR); pwd))

ifeq "$(ARCH)" "win32"
    p1 := //*)
    p2 := /*)
    JES_INSTALL_DIR := $(shell \
	if [ ! -z "$(JES_INSTALL_DIR)" ] ; then \
	    case $(JES_INSTALL_DIR) in \
	     $(p1) \
	       homex=`$(BIN)echo $(JES_INSTALL_DIR) | $(BIN)sed -e 's@^//\([^/]*\)@\1:@'` ; \
	       ;; \
	    $(p2) \
	       homex=`$(BIN)echo $(JES_INSTALL_DIR) | $(BIN)sed -e "s@^/@$(SYSTEMDRIVE)/@"` ; \
	       ;; \
	    esac ; \
	fi ; \
	echo $$homex ; \
	)
    JES_INSTALL_DIR := $(subst \,/,$(JES_INSTALL_DIR))
endif

ifndef BUILD_DIR
    # By using $(DOTS)/ here, the whole examples/ dir can be copied out of
    # the JES_INSTALL_DIR and built by something like
    #     cd .$(DOTS)/examples
    #     setenv JES_INSTALL_DIR .......
    #     gnumake
    BUILD_DIR := $(DOTS)/build
endif

# If JES_JAVA_HOME is defined, use javac and jar from it, else from
# the PATH.
ifdef JES_JAVA_HOME
    JES_JAVA_HOME := $(subst \,/,$(JES_JAVA_HOME))
    JAVAC=$(JES_JAVA_HOME)/bin/javac
    JAR=$(JES_JAVA_HOME)/bin/jar
else
    JAVAC=javac
    JAR=jar
endif

ifdef EXTRA_CLASSPATH
    EXTRA_CLASSPATHx = $(CPSEP)$(EXTRA_CLASSPATH)
endif

JARPATH=$(BUILD_DIR)/bundles
CLASSFILESPATH=$(BUILD_DIR)/classes

LIBS = $(JES_INSTALL_DIR)/lib/framework.jar

ifndef JAVA_FILES
    JAVA_FILES := $(shell ls *.java)
endif

ifndef PROP_FILES
    PROP_FILES = $(shell ls *.properties 2> /dev/null)
endif

ifndef JAR_NAME
   JAR_NAME = $(SRCDIR).jar
endif

CLASSFILES := $(JAVA_FILES:.java=.class)
CLASSFILES := $(patsubst %,$(CLASSFILESPATH)/$(SRCDIR)/%, $(CLASSFILES))

# The default target
all:: 
	$(BIN)mkdir -p $(BUILD_DIR)
