# Copyright (c) 1995-2000 Sun Microsystems, Inc. All Rights Reserved.
# This software is the confidential and proprietary information of Sun
# Microsystems, Inc. ("Confidential Information").  You shall not
# disclose such Confidential Information and shall use it only in
# accordance with the terms of the license agreement you entered into
# with Sun.
#    
# SUN MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
# SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE, OR NON-INFRINGEMENT. SUN SHALL NOT BE LIABLE FOR ANY DAMAGES
# SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
# THIS SOFTWARE OR ITS DERIVATIVES.
############################################################################
# 
# Windows nmake common makefile for JES examples
# 
# These makefiles assume:
# 1.  Either the examples are built in place in <jes install dir>/examples,
#     or, JES_INSTALL_DIR is set to the pathname of where JES is installed.
#
# 2.  Either JES_JAVA_HOME is set to the pathname of a JDK installation,
#     or javac and jar are on your PATH.
# 
# The output from building the examples is left in BUILD_DIR whose
# default value is ..../examples/build
############################################################################
#
# Each makefile in an example must/may define the following variables and then 
# include this file.
#
#    SRCDIR:       The name of the example directory.
#                  Required.
#
#    JAVA_FILES:   .java files to be compiled. The
#                  default is *.java
#
#    PROP_FILES:   .properties files to include.  Unlike for GNUcommon.make,
#                  there is no default.
#
#    EXTRA_FILES:  Extra files to include in the .jar file.  This is a
#                  list of pathnames of the files, relative ./build/classes.
#                  EG:
#                       EXTRA_FILES = example89/T1.class example100/fred.T2.class
#                  would cause the .jar file to include 
#                           example89/T1.class
#                           example100/T2.class
#
#    JAR_NAME:     The name of the jar file to be built.  The
#                  default is $(SRCDIR).jar.  If the value is 'none',
#                  then no jar will be built.
#
#    EXTRA_CLASSPATH:  A classpath segment to include in the compiliation, eg:
#                       EXTRA_CLASSPATH = \
#                          $(JES_INSTALL_DIR)\bundles\log.jar;$(JES_INSTALL_DIR)\bundles\http.jar
#                      Be sure you don't use := defining EXTRA_CLASSPATH if the
#                      definition references a macro which hasn't been defined
#                      yet such as JES_INSTALL_DIR in the above example.
#
#    DOTS:         The the relative path from the example dir to the examples dir.
#                  The default is .. meaning that the example dir is directly contained
#                  in the examples dir.  So, this only has to be defined if there
#                  are intermediate dirs.  For example, suppose the example dir is
#                     examples\group\myexample
#                  Then the GNUmakefile in myexample\ should contain:
#                         SRCDIR = group\myexample
#                         JAR_NAME = myexample.jar
#                         DOTS  = ..\..
#                  And the package for the .java files should be  group.myexample.
#
############################################################################


# This should be defined if examples have multiple levels of directories.
!ifndef DOTS
DOTS =..
!endif


# The path to where JES has been installed; if it is not an
# absolute path, it is relative to the directory where gnumake is
# invoked.
!ifndef JES_INSTALL_DIR
# Assume we are in <install-dir>\examples\xxxx
JES_INSTALL_DIR = ..\..\$(DOTS)
!endif


!ifndef BUILD_DIR
# By using $(DOTS)\ here, the whole examples\ dir can be copied out of
# the JES_INSTALL_DIR and built by something like
#     cd ...\examples
#     setenv JES_INSTALL_DIR .......
#     gnumake
BUILD_DIR = $(DOTS)\build
!endif


# If JES_JAVA_HOME is defined, use javac and jar from it, else from
# the PATH.
!ifdef JES_JAVA_HOME
JAVAC = $(JES_JAVA_HOME)\bin\javac.exe
JAR = $(JES_JAVA_HOME)\bin\jar.exe
!else
JAVAC = javac
JAR = jar
!endif


.SUFFIXES: .java .class .jar

JARPATH = $(BUILD_DIR)\bundles
CLASSFILESPATH= $(BUILD_DIR)\classes

LIBS = $(JES_INSTALL_DIR)\lib\framework.jar

!ifdef JAVA_FILES
!else
JAVA_FILES = *.java
!endif

# This doesn't work in nmake so if there are properties,
# the nmake makefile must name them in a PROP_FILES macro.
#!if DEFINED (PROP_FILES)
#!else
#PROP_FILES = *.properties
#!endif

!ifndef JAR_NAME
JAR_NAME = $(SRCDIR).jar
!endif


CLASSFILES = $(JAVA_FILES:.java=.class)

# This construct doesn't work in nmake.
#xCLASSFILES = $(CLASSFILES:%=$(SRCDIR)\%)
# So, we have to cheat a little.
xCLASSFILES = $(CLASSFILESPATH)\$(SRCDIR)\*.class


all::
	if not exist $(BUILD_DIR) mkdir $(BUILD_DIR)
